==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Base/Common/Object.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Object.cxx
 *  @brief The class Object is the top-most class of Open TURNS
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 11:21:38 +0200 (mer 21 mai 2008) $
 *  Id:      $Id: Object.cxx 815 2008-05-21 09:21:38Z dutka $
 */
#include "Object.hxx"
#include "OSS.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      CLASSNAMEINIT(Object);

      /* Destructor */
      Object::~Object()
      {
        // Nothing to do
      }

      /* String converter */
      String Object::str() const
      {
	return OSS() << "class=" << getClassName();
      }


      /*
       * @fn std::ostream & operator <<(std::ostream & os, const Object & obj)
       * @brief Output stream converter
       * @param os A STL output stream object
       * @param obj The object read by \em os
       * @return A reference to \em os
       */
      std::ostream & operator <<(std::ostream & os, const Object & obj)
      {
        return os << obj.str();
      }





    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Base/Common/Object.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Object.cxx
 *  @brief The class Object is the top-most class of Open TURNS
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: Object.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "Object.hxx"
#include "OSS.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Common
    {

      CLASSNAMEINIT(Object);

      /* Destructor */
      Object::~Object()
      {
        // Nothing to do
      }

      /* String converter */
      String Object::__repr__() const
      {
	return OSS() << "class=" << getClassName();
      }

      /* Pretty string converter */
      String Object::__str__() const
      {
	return __repr__();
      }

      /* Output stream converter */
      std::ostream & operator <<(std::ostream & os, const Object & obj)
      {
        return os << obj.__str__();
      }

    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */
